package de.intevation.flys.artifacts.model;

import java.io.Serializable;

import gnu.trove.TDoubleArrayList;
import gnu.trove.TIntArrayList;


/**
 * This class represents a pool of data triples that consists of 'W', 'Q' and
 * 'Day' data.
 *
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public class WQDay implements Serializable {

    protected TIntArrayList days;

    protected TDoubleArrayList ws;

    protected TDoubleArrayList qs;


    public WQDay() {
        days = new TIntArrayList();
        ws   = new TDoubleArrayList();
        qs   = new TDoubleArrayList();
    }


    public WQDay(int capacity) {
        days = new TIntArrayList(capacity);
        ws   = new TDoubleArrayList(capacity);
        qs   = new TDoubleArrayList(capacity);
    }


    public void add(int day, double w, double q) {
        days.add(day);
        ws.add(w);
        qs.add(q);
    }


    public int size() {
        return days.size();
    }


    public int getDay(int idx) {
        return days.getQuick(idx);
    }


    public double getW(int idx) {
        return ws.getQuick(idx);
    }


    public double getQ(int idx) {
        return qs.getQuick(idx);
    }

    public void removeNaNs() {

        int dest = 0;
        int N = ws.size();

        for (int i = 0; i < N; ++i) {
            double w = ws.getQuick(i);
            double q = qs.getQuick(i);

            if (Double.isNaN(w) || Double.isNaN(q)) {
                continue;
            }

            days.setQuick(dest, days.getQuick(i));
            ws.setQuick(dest, w);
            qs.setQuick(dest, q);
            ++dest;
        }

        if (dest < N) {
            days.remove(dest, N-dest);
            ws  .remove(dest, N-dest);
            qs  .remove(dest, N-dest);
        }
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
